Examples
==================================
Here are some examples to use this packge.
You are suggested to read the API and documentation for more details.

- `Basic tutorial <examples/basic.html>`_
- `Free-boundary VMEC and BOOZ_XFORM <examples/vmec_booz_xform.html>`_
- `Plot plasma and coils using plotly <examples/Plot_with_plotly.html>`_
